.. _Commands:

=============
Berk Commands
=============

Command-line programs in the **Berk** package are described below.


.. _berkCommand:
    
berk
----

.. argparse::
   :filename: ../bin/berk
   :func: makeParser
   :prog: berk
   
   :program:`berk` can perform many tasks, such as fetching data from
   the MeerKAT archive ; calibration and imaging ; cataloging ; and
   distribution of data products.

